Name:           armadillo
Version:        4.695.0
Release:        alt1.svn20150320
Summary:        Fast C++ matrix library with interfaces to LAPACK and ATLAS
Group:          Sciences/Mathematics
License:        LGPLv3+
URL:            http://arma.sourceforge.net/
# fragment from .git/config :
#[svn-remote "svn"]
#  url = https://arma.svn.sourceforge.net/svnroot/arma
#  fetch = :refs/remotes/git-svn
Source:         %name-%version.tar.gz
Source1: Makefile
Source2: %name.pc
Packager: Eugeny A. Rostovtsev (REAL) <real at altlinux.org>

Requires: lib%name = %version-%release

BuildRequires:  cmake gcc-c++ liblapack-devel libhdf5-devel
BuildRequires:  boost-devel libarpack-ng-devel libclapack-devel
BuildPreReq: hdf5-8-tools libsuperlu-devel

%description
Armadillo is a C++ linear algebra library (matrix maths)
aiming towards a good balance between speed and ease of use.
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.
Various matrix decompositions are provided through optional
integration with LAPACK and ATLAS libraries.
A delayed evaluation approach is employed (during compile time)
to combine several operations into one and reduce (or eliminate) 
the need for temporaries. This is accomplished through recursive
templates and template meta-programming.
This library is useful if C++ has been decided as the language
of choice (due to speed and/or integration capabilities), rather
than another language like Matlab (TM) or Octave.
The library is distributed under a license that is useful in
both open-source and commercial contexts.

%package -n lib%name
Summary:        Shared library for the Armadillo C++ library
Group:          System/Libraries
Conflicts: %name < %version-%release

%description -n lib%name
Armadillo is a C++ linear algebra library (matrix maths)
aiming towards a good balance between speed and ease of use.
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.
Various matrix decompositions are provided through optional
integration with LAPACK and ATLAS libraries.
A delayed evaluation approach is employed (during compile time)
to combine several operations into one and reduce (or eliminate) 
the need for temporaries. This is accomplished through recursive
templates and template meta-programming.
This library is useful if C++ has been decided as the language
of choice (due to speed and/or integration capabilities), rather
than another language like Matlab (TM) or Octave.
The library is distributed under a license that is useful in
both open-source and commercial contexts.

This package contains shared library for the Armadillo C++ library.

%package -n lib%name-devel
Summary:        Development files for the Armadillo C++ library
Group:          Development/C++
Requires:       lib%name = %version-%release

%description -n lib%name-devel
Armadillo is a C++ linear algebra library (matrix maths)
aiming towards a good balance between speed and ease of use.
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.
Various matrix decompositions are provided through optional
integration with LAPACK and ATLAS libraries.
A delayed evaluation approach is employed (during compile time)
to combine several operations into one and reduce (or eliminate) 
the need for temporaries. This is accomplished through recursive
templates and template meta-programming.
This library is useful if C++ has been decided as the language
of choice (due to speed and/or integration capabilities), rather
than another language like Matlab (TM) or Octave.
The library is distributed under a license that is useful in
both open-source and commercial contexts.

This package contains files necessary for development using the
Armadillo C++ library.

%package -n lib%name-devel-doc
Summary:        Documentation for the Armadillo C++ library
Group:          Development/Documentation
BuildArch: noarch

%description -n lib%name-devel-doc
Armadillo is a C++ linear algebra library (matrix maths)
aiming towards a good balance between speed and ease of use.
Integer, floating point and complex numbers are supported,
as well as a subset of trigonometric and statistics functions.
Various matrix decompositions are provided through optional
integration with LAPACK and ATLAS libraries.
A delayed evaluation approach is employed (during compile time)
to combine several operations into one and reduce (or eliminate) 
the need for temporaries. This is accomplished through recursive
templates and template meta-programming.
This library is useful if C++ has been decided as the language
of choice (due to speed and/or integration capabilities), rather
than another language like Matlab (TM) or Octave.
The library is distributed under a license that is useful in
both open-source and commercial contexts.

This package contains documentation for development using the
Armadillo C++ library.


%prep
%setup

install -p -m644 %SOURCE2 .
sed -i -e 's|@LIBDIR@|%_libdir|' %name.pc
sed -i -e 's|@VERSION@|%version|' %name.pc

%build
INCS="-include boost/math/complex/acos.hpp"
INCS="$INCS -include boost/math/complex/asin.hpp"
INCS="$INCS -include boost/math/complex/atan.hpp"
%add_optflags -std=c++0x $INCS
export PATH=$PATH:%_libdir/hdf5-seq/bin

cmake \
%if %_lib == lib64
	-DLIB_SUFFIX=64 \
%endif
	-DCMAKE_INSTALL_PREFIX:PATH=%prefix \
	-DCMAKE_C_FLAGS:STRING="%optflags" \
	-DCMAKE_CXX_FLAGS:STRING="%optflags" \
	-DCMAKE_Fortran_FLAGS:STRING="%optflags" \
	-DCMAKE_STRIP:FILEPATH="/bin/echo" \
	.

%make_build VERBOSE=1

#pushd examples
#install -m644 %SOURCE1 .
#make_build
#mv example1 %name-example1
#mv example2 %name-example2
#popd

%install
%makeinstall_std

install -d %buildroot%_pkgconfigdir
install -p -m644 %name.pc %buildroot%_pkgconfigdir

#pushd examples
#install -d %buildroot%_bindir
#install -m755 %name-example? %buildroot%_bindir
#popd

%files -n lib%name
%doc LICENSE* README.txt
%_libdir/*.so.*

%files -n lib%name-devel
%_libdir/*.so
%_includedir/*
%_pkgconfigdir/*
%_datadir/Armadillo

%files -n lib%name-devel-doc
%doc examples *.pdf *.html *.png

%changelog
* Sun Mar 22 2015 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 4.695.0-alt1.svn20150320
- Version 4.695.0

* Thu Jun 26 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 4.349.0-alt2.svn20140624
- Rebuilt with libarpack-ng-devel instead of libarpack-devel

* Wed Jun 25 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 4.349.0-alt1.svn20140624
- Version 4.349.0

* Tue May 27 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 4.300.6-alt1.svn20140523
- Version 4.300.6

* Fri Nov 08 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 3.929.0-alt1.svn20131107
- Version 3.929.0

* Tue Jun 18 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 3.810.0-alt1.svn20130403
- Version 3.810.0

* Fri Feb 01 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 3.6.2-alt1.svn20130201
- Version 3.6.2

* Wed Sep 12 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 3.4.0-alt1.svn20120910
- Version 3.4.0

* Sat Aug 11 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 2.4.2-alt2.svn20111208
- Built with OpenBLAS instead of GotoBLAS2

* Tue Dec 20 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 2.4.2-alt1.svn20111208
- Version 2.4.2

* Wed Aug 17 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 2.3.0-alt1.svn20110804
- Version 2.3.0

* Mon May 09 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.2.0-alt1.svn20110504
- Version 1.2.0

* Wed Apr 13 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.90-alt1.svn20101014.4
- Built with GotoBLAS2 instead of ATLAS

* Thu Mar 17 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.90-alt1.svn20101014.3
- Rebuilt with Boost 1.46.1

* Thu Mar 10 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.90-alt1.svn20101014.2
- Rebuilt for debuginfo

* Tue Oct 26 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.90-alt1.svn20101014.1
- Rebuilt for soname set-versions

* Mon Oct 18 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.90-alt1.svn20101014
- Version 0.9.90

* Wed Jun 16 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.10-alt1.svn20100611.1
- Added pkg-config file

* Fri Jun 11 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.10-alt1.svn20100611
- Version 0.9.10

* Sun May 17 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.6.6-alt1.svn20090409
- Initial build for Sisyphus

* Wed Apr 02 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Updated description

* Wed Mar 24 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Added explicit dependence on libstdc++-devel

* Wed Mar 17 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Simplified specification of directories
- Removed library packages specified by "Requires",
  as library dependencies are detected automatically

* Wed Mar 12 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Modified to generate separate devel package (subsumes previous doc package)
- Removed redundant packages specified by "BuildRequires"
- Added CMake installation prefixes to allow for x86_64

* Wed Feb  4 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Modified to generate separate doc package

* Thu Jan 28 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Added argument to cmake: -DCMAKE_INSTALL_PREFIX=/usr 

* Thu Jan 22 2009  Conrad Sanderson  <conradsand at ieee dot org>
- Initial spec file prepared

